hodge_diamond_cutter: Compute and manipulate Hodge diamonds for many classes of smooth projective varieties
===========================================================================================================

Description
-----------

A collection of Python classes and functions in Sage to deal with Hodge diamonds
(and Hochschild homology) of smooth projective varieties, together with many
constructions.


License
-------

GPL v3


Upstream Contact
----------------

- https://github.com/pbelmans/hodge-diamond-cutter
- https://github.com/passagemath/passagemath-pkg-hodge-diamond-cutter
